Quickstart
==========

.. http://stackoverflow.com/questions/10718767/have-the-same-readme-both-in-markdown-and-restructuredtext

* **freqdemod-quickstart-1** [`open html <http://nbviewer.ipython.org/github/JohnMarohn/FreqDemod/blob/master/freqdemod/docs/freqdemod-quickstart-1.ipynb>`_].  Here we apply ``freqdemod`` to a sine-wave oscillation, obtaining phase *vs* time data from oscillation amplitude *vs* time data.  We fit the phase *vs* time data to a line and obtain a slope that with the known frequency of the sine wave to six decimal places.

.. * **freqdemod-quickstart-2** [:download:`open html <../freqdemod/docs/freqdemod-quickstart-2.html>`].  We generate a frequency-modulated sine-wave signal and use ``freqdemod`` to recover the signal's time-dependent frequency.  Develop a fast curve fitting algorithm.

.. * **freqdemod-quickstart-3** [:download:`open html <../freqdemod/docs/freqdemod-quickstart-3.html>`].  We use ``freqdemod``'s ``fit()`` function to recover transient frequency chenges in two frequency-modulated sine-wave signals (1) a signal that we generate here and (2) a signal generated experimentally by Sarah Nathan in a scanning Kelvin probe force microscope experiment.